==> haskell-wai-http2-extra-0.1.3-262-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-http2-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-http2-extra
version:              0.1.3
visibility:           public
id:                   wai-http2-extra-0.1.3-5fa8rGLCIeJHtdvbe2e1Pj
key:                  wai-http2-extra-0.1.3-5fa8rGLCIeJHtdvbe2e1Pj
license:              MIT
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             WAI utilities for HTTP/2
description:          WAI utilities for HTTP/2
category:             Web
abi:                  7a6bfe7733a412203f0f71c7d1c909ad
exposed:              True
exposed-modules:      Network.Wai.Middleware.Push.Referer
hidden-modules:
    Network.Wai.Middleware.Push.Referer.LRU
    Network.Wai.Middleware.Push.Referer.Manager
    Network.Wai.Middleware.Push.Referer.Multi
    Network.Wai.Middleware.Push.Referer.ParseURL
    Network.Wai.Middleware.Push.Referer.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-http2-extra-0.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-http2-extra-0.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-http2-extra-0.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-http2-extra
hs-libraries:         HSwai-http2-extra-0.1.3-5fa8rGLCIeJHtdvbe2e1Pj
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    http-types-0.12.4-HMggM4fmSOHB2iuVefoAXW
    psqueues-0.2.8.1-D1rbFlFjDOcEAE5h2ZOCFa
    wai-3.2.4-Di5htLW1xGuJXvFRCFw5eQ warp-3.3.30-2F9WVnFrXb042JmtgIncFR
    word8-0.1.3-H2XlNdB8B5CGwrdA9Iis9I

haddock-interfaces:
    /usr/share/doc/haskell-wai-http2-extra/html/wai-http2-extra.haddock

haddock-html:         /usr/share/doc/haskell-wai-http2-extra/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-http2-extra-0.1.3-263-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-http2-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-http2-extra
version:              0.1.3
visibility:           public
id:                   wai-http2-extra-0.1.3-3wYCOxVvmMDtTjD4GqZYa
key:                  wai-http2-extra-0.1.3-3wYCOxVvmMDtTjD4GqZYa
license:              MIT
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             WAI utilities for HTTP/2
description:          WAI utilities for HTTP/2
category:             Web
abi:                  3b1859f00be4214b0c72269bf5e0eb40
exposed:              True
exposed-modules:      Network.Wai.Middleware.Push.Referer
hidden-modules:
    Network.Wai.Middleware.Push.Referer.LRU
    Network.Wai.Middleware.Push.Referer.Manager
    Network.Wai.Middleware.Push.Referer.Multi
    Network.Wai.Middleware.Push.Referer.ParseURL
    Network.Wai.Middleware.Push.Referer.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-http2-extra-0.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-http2-extra-0.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-http2-extra-0.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-http2-extra
hs-libraries:         HSwai-http2-extra-0.1.3-3wYCOxVvmMDtTjD4GqZYa
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    http-types-0.12.4-HMggM4fmSOHB2iuVefoAXW
    psqueues-0.2.8.1-D1rbFlFjDOcEAE5h2ZOCFa
    wai-3.2.4-Di5htLW1xGuJXvFRCFw5eQ warp-3.3.30-E1rdNnVOanbF6TVEQgsanU
    word8-0.1.3-H2XlNdB8B5CGwrdA9Iis9I

haddock-interfaces:
    /usr/share/doc/haskell-wai-http2-extra/html/wai-http2-extra.haddock

haddock-html:         /usr/share/doc/haskell-wai-http2-extra/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
